# smm_client

[![PyPI - Version](https://img.shields.io/pypi/v/smm-client.svg)](https://pypi.org/project/smm-client)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/smm-client.svg)](https://pypi.org/project/smm-client)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install smm-client
```

## License

`smm-client` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
